<?php
namespace FiloBlu\ExpiredSessionRedirect\Observer;

use Magento\Framework\Stdlib\Cookie\CookieMetadataFactory;
use Magento\Framework\Stdlib\Cookie\PhpCookieManager;
use Psr\Log\LoggerInterface;

class DeleteCookie implements \Magento\Framework\Event\ObserverInterface
{

    /**
     * @var LoggerInterface
     */
    private $logger;
    /**
     * @var PhpCookieManager
     */
    private $cookieManager;
    /**
     * @var CookieMetadataFactory
     */
    private $cookieMetadataFactory;


    /**
     * DeleteCookie constructor.
     * @param LoggerInterface $logger
     * @param PhpCookieManager $cookieManager
     * @param CookieMetadataFactory $cookieMetadataFactory
     */
    public function __construct(
        LoggerInterface $logger,
        PhpCookieManager $cookieManager,
        CookieMetadataFactory $cookieMetadataFactory
    ) {
        $this->logger = $logger;
        $this->cookieManager = $cookieManager;
        $this->cookieMetadataFactory = $cookieMetadataFactory;
    }

    /**
     * @param \Magento\Framework\Event\Observer $observer
     */
    public function execute(\Magento\Framework\Event\Observer $observer)
    {
        try {
                if ($this->cookieManager->getCookie(SetCookie::COOKIE_NAME) !== null) {
                    //delete cookie
                    $metadata = $this->cookieMetadataFactory->createPublicCookieMetadata()->setPath('/');
                    $this->cookieManager->deleteCookie(SetCookie::COOKIE_NAME, $metadata);
                }

        } catch (\Exception $e) {
            $this->logger->critical($e->getMessage());
        } catch (\Throwable $t) {
            $this->logger->critical($t->getMessage());
        }
    }
}
