<?php
namespace FiloBlu\ExpiredSessionRedirect\Setup;

use Magento\Framework\Setup\InstallDataInterface;
use Magento\Framework\Setup\ModuleContextInterface;
use Magento\Framework\Setup\ModuleDataSetupInterface;
use Magento\Cms\Model\PageFactory;
use Magento\Framework\Filesystem;
use Magento\Framework\Module\Dir\Reader;
use Psr\Log\LoggerInterface;

class InstallData implements InstallDataInterface
{

    /**
     * @var PageFactory
     */
    private $pageFactory;

    /**
     * @var Filesystem
     */
    private $filesystem;
    /**
     * @var Reader
     */
    private $reader;
    /**
     * @var LoggerInterface
     */
    private $logger;

    /**
     * InstallData constructor.
     * @param PageFactory $pageFactory
     * @param Filesystem $filesystem
     * @param Reader $reader
     * @param LoggerInterface $logger
     */
    public function __construct(
        PageFactory $pageFactory,
        Filesystem $filesystem,
        Reader $reader,
        LoggerInterface $logger)
    {
        $this->pageFactory = $pageFactory;
        $this->filesystem = $filesystem;
        $this->reader = $reader;
        $this->logger = $logger;
    }

    /**
     * @param ModuleDataSetupInterface $setup
     * @param ModuleContextInterface $context
     */
    public function install(ModuleDataSetupInterface $setup, ModuleContextInterface $context)
    {
        try{

            $started =false;
            if (version_compare($context->getVersion(), '0.0.1') < 0) {

                $this->uploadImage();
                $setup->startSetup();
                $started =true;
                $page = $this->pageFactory->create();
                $page->setTitle('Customer Session Expired Landing')
                    ->setIdentifier('customer-session-expired-landing')
                    ->setIsActive(true)
                    ->setPageLayout('1column')
                    ->setStores(array(0))
                    ->setContent('<p>&nbsp;</p>
                                <p>&nbsp;</p>
                                <p style="text-align: center;">&nbsp;</p>
                                <p style="text-align: center;">&nbsp;</p>
                                <p style="text-align: center;">&nbsp;</p>
                                <table style="height: 381px; margin-left: auto; margin-right: auto; width: 1069px;">
                                <tbody>
                                <tr>
                                <td style="width: 394.117px;"><img src="/media/wysiwyg/sessionExpired.png" alt="Session Expired" width="374" height="420"></td>
                                <td style="width: 1721.88px;">
                                <p style="text-align: center;"><span style="line-height: 64px;">Dear customer, your session is expired . Please login again to continue shopping.</span></p>
                                <p style="text-align: center;"><a title="Login Page" href="customer/account/login"><span style="line-height: 64px;">Login Page</span> </a></p>
                                </td>
                                </tr>
                                </tbody>
                                </table>')
                    ->save();
                $setup->endSetup();
                $started =false;
            }


        }catch (\Exception $e){
         $this->logger->critical($e->getMessage());
            if($started){
                $setup->endSetup();
            }

        }catch (\Throwable $t){
            $this->logger->critical($t->getMessage());
            if($started){
                $setup->endSetup();
            }

        }

    }

    /**
     * @throws \Magento\Framework\Exception\FileSystemException
     */
    protected function uploadImage(){
        $imgFileName = $this->reader->getModuleDir(\Magento\Framework\Module\Dir::MODULE_VIEW_DIR,'FiloBlu_ExpiredSessionRedirect').'/media/sessionExpired.png';
        $mediaUrl=$this->filesystem->getDirectoryWrite(\Magento\Framework\App\Filesystem\DirectoryList::MEDIA);
        file_put_contents($mediaUrl->getAbsolutePath().'wysiwyg/sessionExpired.png',file_get_contents($imgFileName));
    }

}